// CGame.cpp

#include "CGame.h"

/*
 *====================================================================
 *					InitBackground()
 *
 * desc: Loads the background bitmap that will be used in the game
 *====================================================================
 */
void CGame::InitBackground()
{
	m_BackgroundSurface = SDL_LoadBMP("images/bg.bmp");
}

/*
 *====================================================================
 *					DrawBackground()
 *
 * desc: Draw's the background onto the screen
 * @param: Takes an SDL_Surface named background that will be blitted 
 *         onto the screen
 *====================================================================
 */
void CGame::DrawBackground(SDL_Surface *background, SDL_Surface *gameScreen)
{
	SDL_Rect dest;
	dest.x = 0;
	dest.y = 0;
  SDL_BlitSurface(background, NULL, gameScreen, &dest);
}

/*
 *====================================================================
 *					InitImages()
 *
 * desc: Initializes all the game's images and loads them up to be
 *			 used
 * @param: A CBall, two CPaddles, and a CGame to initialize the game
 *         ball image, the two paddle images and the game's background
 *====================================================================
 */
void CGame::InitImages(CBall &ball, CPaddle &player1, CPaddle &player2, CGame &background)
{
	player1.InitPaddle();
	player2.InitPaddle();
	background.InitBackground();
	ball.InitBall();
	m_Font1 = Text.initFont("data/font1");
	m_Font2 = Text.initFont("data/font1"),1,0,0;
	m_Font3 = Text.initFont("data/font3");
}

/*
 *====================================================================
 *					DrawScene()
 *
 * desc: Draw's everything initialized to the game board including the
 *			 game paddles, ball, and background.
 * @param: A CBall, two CPaddles, and a CGame to load and draw every-
 *         thing
 *====================================================================
 */
void CGame::DrawScene(CBall &ball, CPaddle &player1, CPaddle &player2, CGame &game)
{
	// Draw the background
	game.DrawBackground(game.m_BackgroundSurface, m_GameScreen);

	// Draw the game ball
	ball.DrawBall(ball.m_BallSurface, m_GameScreen);

	// Draw the game paddles
	player1.DrawPaddle(player1.m_PaddleSurface, m_GameScreen);
	player2.DrawPaddle(player1.m_PaddleSurface, m_GameScreen);

	// Prints the players' scores
	Text.drawString(game.m_BackgroundSurface, m_Font3, 10, 1,  "Player 1 Score: %d", m_Score[0]);
	Text.drawString(game.m_BackgroundSurface, m_Font3, 550, 1, "Player 2 Score: %d", m_Score[1]);

  SDL_Flip(m_GameScreen);
}

/*
 *====================================================================
 *					InitGame()
 *
 * desc: Initializes SDL itself and loads all the video settings and
 *			 such
 *====================================================================
 */
void CGame::InitGame()
{
	m_Score[0] = 0;
	m_Score[1] = 0;
  if ( SDL_Init(SDL_INIT_AUDIO|SDL_INIT_VIDEO) < 0 )
  {
    printf("Unable to init SDL: %s\n", SDL_GetError());
    exit(1);
  }
  atexit(SDL_Quit);
}

/*
 *====================================================================
 *					CalculateFPS
 *
 * desc: Calculates the frame rate of the game
 *====================================================================
 */
void CGame::CalculateFPS()
{
	static float g_fFramesPerSec = 0.0f;
	static float g_fLastFrameTime = 0.0f;
	static float g_fFrameTime = 0.0f;

	//get the current time in seconds
	float g_fCurrTime = SDL_GetTicks() * 0.001f;

	//store the time elapsed since the last frame and the current frame time for next time
	m_fElapsedTime = g_fCurrTime - g_fFrameTime;
	g_fFrameTime = g_fCurrTime;

	++g_fFramesPerSec;

	//has one second passed?
	if((g_fCurrTime - g_fLastFrameTime) > 1.0f)
	{
		g_fLastFrameTime = g_fCurrTime;
		m_fCurrFPS = g_fFramesPerSec;
		g_fFramesPerSec = 0.0f;
	}
}