// CVector.cpp

#include "CVector.h"


/*
 *====================================================================
 *          Copy Constructor          
 *																   
 * desc: Copies one vector to equal	another desired one				 
 * @param:  A Vector class           
 *====================================================================
 */
CVector::CVector(const CVector &Rhs)
{
	vector_2d[0] = Rhs.vector_2d[0];
	vector_2d[1] = Rhs.vector_2d[1];
}

/*
 *====================================================================
 *				  Overloaded Constructor
 *
 * desc: Overloaded Constructor for CVector
 * @param: Takes two scalar values and asigns them to a 2D vector
 *====================================================================
 */
CVector::CVector(scalar X, scalar Y)
{
	vector_2d[0] = X;
	vector_2d[1] = Y;
}

/*
 *====================================================================
 *          Overloaded += operator
 *
 * desc: Adds 2D Vectors to each other using the shorthand += op
 * @param: Takes a reference to a CVector
 *====================================================================
 */
const CVector& CVector::operator +=(const CVector& Rhs)
{
	vector_2d[0] += Rhs.vector_2d[0];
	vector_2d[1] += Rhs.vector_2d[1];
	return *this;
}

/*
 *====================================================================
 *					Overloaded -= Operator
 *
 * desc: Subtracs 2D Vectors from one another using the shorhand -= op
 * @param: Takes a reference to a CVector
 *====================================================================
 */
const CVector& CVector::operator -=(const CVector& Rhs)
{
	vector_2d[0] -= Rhs.vector_2d[0];
	vector_2d[1] -= Rhs.vector_2d[1];
	return *this;
}


/*
 *====================================================================
 *					Overloaded != Operator
 *
 * desc: Can compare CVectors with !=
 * @param: Takes a reference to a CVector
 *====================================================================
 */
inline const bool CVector::operator !=(const CVector& Rhs) const
{
	return !(*this == Rhs);
}

/*
 *====================================================================
 *          Overloaded == Operator
 *
 * desc: Can compare CVectors with ==
 * @param: Takes a reference to a CVector
 *====================================================================
 */
inline const bool CVector::operator ==(const CVector &Rhs) const
{
	return ((vector_2d[0] == Rhs.vector_2d[0]) && (vector_2d[1] == Rhs.vector_2d[1]));
}

/*
 *====================================================================
 *					Dot Product
 *
 * desc: Returns the dot product of a CVector's x,y coordinates
 * @param: Takes a reference to a CVector. CVector &Lhs is what your
 *				 assigning the dot product to, CVector &Rhs is what your
 *				 comparing it to.
 *====================================================================
 */
const CVector& CVector::DotProduct(CVector &Lhs, const CVector &Rhs) const
{
	scalar x, y;
	x = (Lhs.vector_2d[0] * Rhs.vector_2d[0]);
	y = (Lhs.vector_2d[1] * Rhs.vector_2d[1]);
	Lhs.dot_product[0] = x;
	Lhs.dot_product[1] = y;
	return *this;
}
